@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: hostfile.c,v 1.16 2004/03/22 09:28:30 alec Exp $
+ *  $Id: hostfile.c,v 1.21 2004/04/20 08:24:58 alec Exp $
  */
 
 #include <stdio.h>
@@ -34,13 +34,17 @@ unsigned long inet_addr(char *);
 void reload(GLOBAL *g, struct hostfile_module *hm)
 {
 	FILE *fh;
-	QUERY_HANDLE *res;
+	QUERY_HANDLE *res, *res1;
 	unsigned char *query;
-	int i, nc=0, n=2;
+	int i, j, m, k=2, gc=0, nc=0, n=2;
 
 	struct net *nets = (struct net *) malloc(sizeof(struct net));
 	char *netnames = strdup(hm->networks);	
 	char *netname = strdup(netnames);
+	
+	struct group *ugps = (struct group *) malloc(sizeof(struct group));
+	char *groupnames = strdup(hm->usergroups);	
+	char *groupname = strdup(groupnames);
 
 	while( n>1 ) {
 		
@@ -48,13 +52,14 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 
 		if( strlen(netname) ) {
 
-			if( res = g->db_pquery("SELECT name, domain, address, INET_ATON(mask) AS mask FROM networks WHERE UPPER(name)=UPPER('?')",netname)) {
+			if( res = g->db_pquery("SELECT name, domain, address, INET_ATON(mask) AS mask, interface FROM networks WHERE UPPER(name)=UPPER('?')",netname)) {
 
 				if(res->nrows) {
 
 			    		nets = (struct net *) realloc(nets, (sizeof(struct net) * (nc+1)));
 					nets[nc].name = strdup(g->db_get_data(res,0,"name"));
 					nets[nc].domain = strdup(g->db_get_data(res,0,"domain"));
+					nets[nc].interface = strdup(g->db_get_data(res,0,"interface"));
 					nets[nc].address = inet_addr(g->db_get_data(res,0,"address"));
 					nets[nc].mask = inet_addr(g->db_get_data(res,0,"mask"));
 					nc++;
@@ -66,18 +71,52 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	free(netname); free(netnames);
 
 	if(!nc)
-		if( (res = g->db_query("SELECT name, domain, address, INET_ATON(mask) AS mask FROM networks"))!=NULL ) {
+		if( (res = g->db_query("SELECT name, domain, address, INET_ATON(mask) AS mask, interface FROM networks"))!=NULL ) {
 
 			for(nc=0; nc<res->nrows; nc++) {
 				
 				nets = (struct net*) realloc(nets, (sizeof(struct net) * (nc+1)));
 				nets[nc].name = strdup(g->db_get_data(res,nc,"name"));
 				nets[nc].domain = strdup(g->db_get_data(res,nc,"domain"));
+				nets[nc].interface = strdup(g->db_get_data(res,0,"interface"));
 				nets[nc].address = inet_addr(g->db_get_data(res,nc,"address"));
 				nets[nc].mask = inet_addr(g->db_get_data(res,nc,"mask"));
 			}
 			g->db_free(res);
 		}
+
+	while( k>1 ) {
+		
+		k = sscanf(groupnames, "%s %[a-zA-Z0-9- ]", groupname, groupnames);
+
+		if( strlen(groupname) ) {
+
+			if( res = g->db_pquery("SELECT name, id FROM usergroups WHERE UPPER(name)=UPPER('?')",groupname)) {
+
+				if(res->nrows) {
+
+			    		ugps = (struct group *) realloc(ugps, (sizeof(struct group) * (gc+1)));
+					ugps[gc].name = strdup(g->db_get_data(res,0,"name"));
+					ugps[gc].id = atoi(g->db_get_data(res,0,"id"));
+					gc++;
+				}
+	    			g->db_free(res);
+			}				
+		}
+	}
+	free(groupname); free(groupnames);
+
+	if(!gc)
+		if( (res = g->db_query("SELECT name, id FROM usergroups ORDER BY name"))!=NULL ) {
+
+			for(gc=0; gc<res->nrows; gc++) {
+				
+				ugps = (struct group*) realloc(ugps, (sizeof(struct group) * (gc+1)));
+				ugps[gc].name = strdup(g->db_get_data(res,gc,"name"));
+				ugps[gc].id = atoi(g->db_get_data(res,gc,"id"));
+			}
+			g->db_free(res);
+		}
 	
 	fh = fopen(hm->file, "w");
 	if(fh)
@@ -85,9 +124,9 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 		fprintf(fh, "%s", hm->prefix);
 		
 		if(hm->skip_dev_ips)
-			query = strdup("SELECT LOWER(name) AS name, mac, INET_NTOA(ipaddr) AS ip, access FROM nodes WHERE ownerid<>0 ORDER BY ipaddr");
+			query = strdup("SELECT LOWER(name) AS name, mac, INET_NTOA(ipaddr) AS ip, ownerid, access FROM nodes WHERE ownerid<>0 ORDER BY ipaddr");
 		else
-			query = strdup("SELECT LOWER(name) AS name, mac, INET_NTOA(ipaddr) AS ip, access FROM nodes ORDER BY ipaddr");
+			query = strdup("SELECT LOWER(name) AS name, mac, INET_NTOA(ipaddr) AS ip, ownerid, access FROM nodes ORDER BY ipaddr");
 			
 		if( (res = g->db_query(query))!=NULL ) {
 		
@@ -102,13 +141,24 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 				if(ip && mac && access) {
 					
 					unsigned long inet = inet_addr(ip);
-					int j;
-					
+					// networks test
 					for(j=0; j<nc; j++)
 						if(nets[j].address == (inet & nets[j].mask)) 
 							break;
+					// groups test
+					if(strlen(hm->usergroups))
+						if( res1 = g->db_pquery("SELECT usergroupid FROM userassignments WHERE userid=?", g->db_get_data(res,i,"ownerid"))) {
+							for(k=0; k<res1->nrows; k++) {
+								int groupid = atoi(g->db_get_data(res1, k, "usergroupid"));
+								for(m=0; m<gc; m++) 
+									if(ugps[m].id==groupid) 
+										break;
+								if(m!=gc) break;
+							}
+							g->db_free(res1);
+						}
 					
-					if( j != nc ) {
+					if( j!=nc && (m!=gc || (m==gc && !strlen(hm->usergroups))) ) {
 
 						unsigned char *pattern, *s;
 
@@ -120,6 +170,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 						s = strdup(pattern);
 						g->str_replace(&s, "%domain", nets[j].domain);
 						g->str_replace(&s, "%net", nets[j].name);
+						g->str_replace(&s, "%if", nets[j].interface);
 						g->str_replace(&s, "%i", ip);
 						g->str_replace(&s, "%m", mac);
 						g->str_replace(&s, "%n", name);
@@ -145,9 +196,15 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	for(i=0;i<nc;i++) {
 		free(nets[i].name);
 		free(nets[i].domain);	
+		free(nets[i].interface);
 	}
 	free(nets);
 	
+	for(i=0;i<gc;i++) {
+		free(ugps[i].name);
+	}
+	free(ugps);
+	
 	free(hm->prefix);
 	free(hm->append);
 	free(hm->grant);	
@@ -155,6 +212,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	free(hm->file);
 	free(hm->command);
 	free(hm->networks);
+	free(hm->usergroups);
 }
 
 struct hostfile_module * init(GLOBAL *g, MODULE *m)
@@ -191,6 +249,8 @@ struct hostfile_module * init(GLOBAL *g, MODULE *m)
 	hm->command = strdup(g->iniparser_getstring(ini, s, ""));
 	free(s); s = g->str_concat(instance, ":networks");
 	hm->networks = strdup(g->iniparser_getstring(ini, s, ""));
+	free(s); s = g->str_concat(instance, ":usergroups");
+	hm->usergroups = strdup(g->iniparser_getstring(ini, s, ""));
 	
 	g->iniparser_freedict(ini);
 	free(instance);
