@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.22 2004/03/11 18:37:15 lukasz Exp $
  */
 
 /*
@@ -35,7 +35,7 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function LMSDB_driver_mysql($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.21 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.22 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 	
@@ -52,9 +52,18 @@ class LMSDB_driver_mysql extends LMSDB_common
 			$this->_dbuser = $dbuser;
 			$this->_driver_selectdb($dbname);
 		}
+		else
+		{
+			$this->_error = TRUE;
+		}
 		return $this->_dblink;
 	}
 
+	function _driver_geterror()
+	{
+		return mysql_error($this->_dblink);
+	}
+
 	function _driver_disconnect()
 	{
 		return mysql_close($this->_dblink);
@@ -69,13 +78,11 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function _driver_execute($query)
 	{
+		$this->_query = $query;
 		if($this->_result = mysql_query($query,$this->_dblink))
-		{
-			$this->_query = $query;
 			$this->_error = FALSE;
-		}else
-			$this->_error = mysql_error($this->_dblink);
-
+		else
+			$this->_error = TRUE;
 		return $this->_result;
 	}
 
