@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 1.45 2004/03/02 20:38:28 lexx Exp $
+ *  $Id: Session.class.php,v 1.48 2004/04/01 12:31:57 alec Exp $
  */
 
 class Session {
@@ -31,18 +31,20 @@ class Session {
 	var $logname;
 	var $passwd;
 	var $islogged = FALSE;
-	var $ADB;
 	var $last;
 	var $lastip;
 	var $error;
-	var $_version = '1.3.1 Maybourne';
-	var $_revision = '$Revision: 1.45 $';
+	var $_version = '1.3-cvs';
+	var $_revision = '$Revision: 1.48 $';
 
 	function Session(&$DB,$timeout = 600)
 	{
 		session_start();
 		$this->DB = &$DB;
-		$loginform = $_POST[loginform];
+		if($_GET['override'])
+			$loginform = $_GET['loginform'];
+		else
+			$loginform = $_POST['loginform'];
 		if(isset($loginform))
 		{
 			$this->login = $loginform[login];
@@ -114,7 +116,7 @@ class Session {
 	{
 		if( (time()-$_SESSION[session_timestamp]) > $timeout )
 		{
-			$this->error=str_replace("%s",$timeout,gettext("Your login time was timetout. (%s sec)"));
+			$this->error="Przekroczye limit czasu bezczynnoci (".$timeout." sekund).";
 			return FALSE;
 		}
 		else
@@ -133,9 +135,9 @@ class Session {
 		else 
 		{
 			if(isset($this->login))
-				$this->error=gettext("Wrong username or password");
+				$this->error="Bdne haso lub nazwa uytkownika.";
 			else
-				$this->error=gettext("Please login yourself");
+				$this->error="Prosz si zalogowa.";
 			return FALSE;
 		}
 	}
