@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.59 2004/03/03 23:37:36 lukasz Exp $
+ *  $Id: common.php,v 1.60 2004/03/14 21:41:33 lukasz Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -237,7 +237,7 @@ function ip_long($sip)
 	if(check_ip($sip)){
 		return sprintf('%u',ip2long($sip));
 	}else{
-		return false;
+		return 0;
 	}
 }
 
