@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgradedb.php,v 1.7 2004/03/14 12:38:31 lukasz Exp $
+ *  $Id: upgradedb.php,v 1.15 2004/04/23 08:29:52 alec Exp $
  */
 
-define(DBVERSION, '2004031402'); // here should be always the newest version of database!
+define(DBVERSION, '2004042300'); // here should be always the newest version of database!
 // it placed here to avoid read disk every time when we call this file.
 
 /*
@@ -49,8 +49,11 @@ if($dbversion = $DB->GetOne('SELECT keyvalue FROM dbinfo WHERE keytype = ?',arra
 			sort($pendingupgrades);
 			foreach($pendingupgrades as $upgrade)
 			{
-				@include($_LIB_DIR.'/upgradedb/'.$_DBTYPE.'.'.$upgrade.'.php');
+				include($_LIB_DIR.'/upgradedb/'.$_DBTYPE.'.'.$upgrade.'.php');
 			}
 		}
 	}
+
+$layout['dbschversion'] = DBVERSION;
+
 ?>
