@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: admininfo.php,v 1.23 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: admininfo.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
  */
 
 if(!$LMS->AdminExists($_GET['id']))
@@ -38,7 +38,6 @@ foreach($rights as $right)
 	if($access['table'][$right]['name'])
 		$accesslist[] = $access['table'][$right]['name'];
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('admininfo',$admininfo);
 $SMARTY->assign('accesslist',$accesslist);
 $SMARTY->display('admininfo.html');
