@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancelist.php,v 1.30 2004/03/11 17:24:21 lukasz Exp $
+ *  $Id: balancelist.php,v 1.31 2004/04/08 07:56:38 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -49,11 +49,8 @@ $layout['pagetitle'] = "Bilans finansowy";
 $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('start',$start);
-$SMARTY->assign('prev',$prev);
-$SMARTY->assign('next',$next);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('pagelimit',$pagelimit);
-$SMARTY->assign('start',$start);
 $SMARTY->display('balancelist.html');
 
 ?>
