@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,17 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dblist.php,v 1.19 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: dblist.php,v 1.21 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle]="Bazy danych";
+$layout['pagetitle'] = "Bazy danych";
 
 $dblist = $LMS->DatabaseList();
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("dblist",$dblist);
-$SMARTY->display("header.html");
-$SMARTY->display("dblist.html");
-$SMARTY->display("footer.html");
+$SMARTY->assign('dblist',$dblist);
+$SMARTY->display('header.html');
+$SMARTY->display('dblist.html');
+$SMARTY->display('footer.html');
 
 ?>
\ No newline at end of file
