@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailingsend.php,v 1.25 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: mailingsend.php,v 1.26 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Mailing";
@@ -44,7 +44,6 @@ if($mailing['subject']=="")
 
 if($error)
 {
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->assign('error',$error);
 	$SMARTY->assign('mailing',$mailing);
 	$SMARTY->display('mailing.html');
@@ -55,7 +54,6 @@ else
 	$mailing['body'] = textwrap($mailing['body']);
 	$mailing['body'] = str_replace("\r", "", $mailing['body']);
 	$SMARTY->assign('mailing',$mailing);
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('header.html');
 	$SMARTY->display('mailingsend.html');
 	$emails = $LMS->Mailing($mailing);
