@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: print.php,v 1.29 2004/04/01 20:05:28 alec Exp $
+ *  $Id: print.php,v 1.34 2004/04/25 13:25:34 alec Exp $
  */
 
 switch($_GET['type'])
@@ -30,8 +30,8 @@ switch($_GET['type'])
 		switch($_POST['filter'])
 		{
 			case 0:
-				$layout['pagetitle'] = 'Lista uytkownikw'.($_POST['network'] ? ' sieci '.$LMS->GetNetworkName($_POST['network']) : '');
-				$SMARTY->assign('userlist', $LMS->GetUserList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network']));
+				$layout['pagetitle'] = 'Lista uytkownikw'.($_POST['network'] ? ' sieci '.$LMS->GetNetworkName($_POST['network']) : '').($_POST['usergroup'] ? ' w grupie '.$LMS->UsergroupGetName($_POST['usergroup']) : '');
+				$SMARTY->assign('userlist', $LMS->GetUserList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['usergroup']));
 			break;
 			case 1:
 				$layout['pagetitle'] = 'Lista uytkownikw zainteresowanych ';
@@ -42,12 +42,12 @@ switch($_GET['type'])
 				$SMARTY->assign('userlist', $LMS->GetUserList($_POST['order'].','.$_POST['direction'], $_POST['filter']));
 			break;
 			case 3:
-				$layout['pagetitle'] = 'Lista uytkownikw podczonych'.($_POST['network'] ? ' do sieci '.$LMS->GetNetworkName($_POST['network']) : '');
-				$SMARTY->assign('userlist', $LMS->GetUserList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network']));
+				$layout['pagetitle'] = 'Lista uytkownikw podczonych'.($_POST['network'] ? ' do sieci '.$LMS->GetNetworkName($_POST['network']) : '').($_POST['usergroup'] ? ' w grupie '.$LMS->UsergroupGetName($_POST['usergroup']) : '');
+				$SMARTY->assign('userlist', $LMS->GetUserList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['usergroup']));
 			break;
 			case 4: 
-				$layout['pagetitle'] = 'Lista uytkownikw odczonych'.($_POST['network'] ? ' od sieci '.$LMS->GetNetworkName($_POST['network']) : '');
-				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction'], NULL, $_POST['network']))
+				$layout['pagetitle'] = 'Lista uytkownikw odczonych'.($_POST['network'] ? ' od sieci '.$LMS->GetNetworkName($_POST['network']) : '').($_POST['usergroup'] ? ' w grupie '.$LMS->UsergroupGetName($_POST['usergroup']) : '');
+				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction'], NULL, $_POST['network'], $_POST['usergroup']))
 				{
 				unset($userlist['total']);
 				unset($userlist['state']);
@@ -63,8 +63,8 @@ switch($_GET['type'])
 				$SMARTY->assign('userlist', $nuserlist);
 			break;
 			case 5: 
-				$layout['pagetitle'] = 'Lista uytkownikw zaduonych'.($_POST['network'] ? ' w sieci '.$LMS->GetNetworkName($_POST['network']) : '');
-				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction'], NULL, $_POST['network']))
+				$layout['pagetitle'] = 'Lista uytkownikw zaduonych'.($_POST['network'] ? ' w sieci '.$LMS->GetNetworkName($_POST['network']) : '').($_POST['usergroup'] ? ' w grupie '.$LMS->UsergroupGetName($_POST['usergroup']) : '');
+				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction'], NULL, $_POST['network'], $_POST['usergroup']))
 				{
 				unset($userlist['total']);
 				unset($userlist['state']);
@@ -80,8 +80,8 @@ switch($_GET['type'])
 				$SMARTY->assign('userlist', $nuserlist);
 			break;
 			case 6: 
-				$layout['pagetitle'] = 'Lista uytkownikw bez komputerw';
-				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction']))
+				$layout['pagetitle'] = 'Lista uytkownikw bez komputerw'.($_POST['usergroup'] ? ' w grupie '.$LMS->UsergroupGetName($_POST['usergroup']) : '');
+				if($userlist=$LMS->GetUserList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['usergroup']))
 				{
 				unset($userlist['total']);
 				unset($userlist['state']);
@@ -222,6 +222,46 @@ switch($_GET['type'])
 		$SMARTY->assign('balancelist', $bbalancelist);
 		$SMARTY->display('printbalancelist.html');
 	break;
+
+	case 'incomereport': /********************************************/
+	
+		$from = $_POST['from'];
+		$to = $_POST['to'];
+
+		// date format 'yyyy/mm/dd'	
+		list($year, $month, $day) = split('/',$from);
+		$date['from'] = mktime(0,0,0,$month,$day,$year);
+		
+		if($to) {
+			list($year, $month, $day) = split('/',$to);
+			$date['to'] = mktime(0,0,0,$month,$day,$year);
+		} else {
+			$to = date("Y/m/d",time());
+			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
+		}
+		
+		$layout['pagetitle'] = 'czny przychd bezrachunkowy za okres '.($from ? ' od '.$from.' ' : '').'do '.$to;
+
+		$incomelist = $LMS->GetIncomeList($date);
+		$totalincomelist = $LMS->GetTotalIncomeList($date);
+		$SMARTY->assign('incomelist', $incomelist);
+		$SMARTY->assign('totalincomelist', $totalincomelist);
+		$SMARTY->display('printincomereport.html');
+	break;
+
+	case 'liabilityreport': /********************************************/
+	
+		if($_POST['day']) {
+			list($year, $month, $day) = split('/',$_POST['day']);
+			$reportday = mktime(0,0,0,$month,$day,$year);
+		} else 
+			$reportday = time();
+		
+		$layout['pagetitle'] = 'Raport wierzytelnoci na dzie '.date('Y/m/d', $reportday);
+
+		$SMARTY->assign('reportlist', $LMS->LiabilityReport($reportday, $_POST['order'].','.$_POST['direction'], $_POST['user']));
+		$SMARTY->display('printliabilityreport.html');
+	break;
 		
 	default: /*******************************************************/
 		$layout['pagetitle'] = 'Wydruki';
@@ -231,6 +271,7 @@ switch($_GET['type'])
 		$SMARTY->assign('users', $LMS->GetUserNames());
 		$SMARTY->assign('admins', $admins);
 		$SMARTY->assign('networks', $LMS->GetNetworks());
+		$SMARTY->assign('usergroups', $LMS->UsergroupGetAll());
 		$SMARTY->assign('printmenu', $_GET['menu']);
 		$SMARTY->display('printindex.html');
 	break;
