@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useredit.php,v 1.50 2003/12/04 03:43:51 lukasz Exp $
+ *  $Id: useredit.php,v 1.62 2004/04/17 17:00:47 chilek Exp $
  */
 
 $userdata = $_POST['userdata'];
@@ -46,13 +46,22 @@ elseif($_GET['action'] == 'addassignment')
 {
 	$period = sprintf('%d',$_POST['period']);
 
-	if($period < 0 || $period > 2)
-		$period = 0;
+	if($period < 0 || $period > 3)
+		$period = 1;
 
 	switch($period)
 	{
 		case 0:
 			$at = sprintf('%d',$_POST['at']);
+			
+			if($at < 1)
+				$at = 1;
+			elseif($at > 7)
+				$at = 7;
+		break;
+
+		case 1:
+			$at = sprintf('%d',$_POST['at']);
 			if($at == 0)
 			{
 				$at = 1 + date('d',time());
@@ -66,16 +75,21 @@ elseif($_GET['action'] == 'addassignment')
 				$at = 28;
 		break;
 
-		case 1:
-			$at = sprintf('%d',$_POST['at']);
-			
-			if($at < 1)
-				$at = 1;
-			elseif($at > 7)
-				$at = 7;
+		case 2:
+			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($_POST['at'])))
+				$error[] = 'Niepoprawny format daty';
+			else {
+				list($d,$m) = split('/',trim($_POST['at']));
+				if($d>30 || $d<1)
+					$error[] = 'Niepoprawna liczba dni w miesicu';
+				if($m>3 || $m<1)
+					$error[] = 'Niepoprawny numer miesica (max.3)';
+				
+				$at = ($m-1) * 100 + $d;
+			}
 		break;
 
-		case 2:
+		case 3:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($_POST['at'])))
 				$error[] = 'Niepoprawny format daty';
 			else
@@ -85,13 +99,54 @@ elseif($_GET['action'] == 'addassignment')
 		break;
 	}
 
+	if(trim($_POST['datefrom'] == ''))
+		$from = 0;
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($_POST['datefrom'])))
+	{
+		list($y, $m, $d) = split('/', trim($_POST['datefrom']));
+		if(checkdate($m, $d, $y))
+			$from = mktime(0, 0, 0, $m, $d, $y);
+		else
+			$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+	}
+	else
+		$error[] = 'Pocztek okresu naliczania jest niepoprawny!';
+
+	if(trim($_POST['dateto'] == ''))
+		$to = 0;
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($_POST['dateto'])))
+	{
+		list($y, $m, $d) = split('/', trim($_POST['dateto']));
+		if(checkdate($m, $d, $y))
+			$to = mktime(23, 59, 59, $m, $d, $y);
+		else
+			$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+	}
+	else
+		$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+
+	if($to < $from && $to != 0 && $from != 0)
+		$error[] = 'Zakres dat jest niepoprawny!';
+
 	if($LMS->TariffExists($_POST['tariffid']) && !$error)
-		$LMS->AddAssignment(array('tariffid' => $_POST['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$_POST['invoice'])));
-		
+		$LMS->AddAssignment(array('tariffid' => $_POST['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$_POST['invoice']), 'datefrom' => $from, 'dateto' => $to ));
 	header('Location: ?m=userinfo&id='.$_GET['id']);
 	die;
 			
 }
+elseif($_GET['action'] == 'usergroupdelete')
+{
+	$LMS->UserassignmentDelete(array('userid' => $_GET['id'], 'usergroupid' => $_GET['usergroupid']));
+	header('Location: ?m=userinfo&id='.$_GET['id']);
+	die;
+}
+elseif($_GET['action'] == 'usergroupadd')
+{
+	if ($LMS->UsergroupExists($_POST['usergroupid']))
+		$LMS->UserassignmentAdd(array('userid' => $_GET['id'], 'usergroupid' => $_POST['usergroupid']));
+	header('Location: ?m=userinfo&id='.$_GET['id']);
+	die;
+}
 elseif(isset($userdata))
 {
 
@@ -113,10 +168,10 @@ elseif(isset($userdata))
 	if($userdata['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$userdata['zip']))
 		$error['zip'] = 'Podany kod pocztowy jest bdny!';
 
-	if($userdata['gguin'] == 0)
-		unset($userdata['gguin']);
+	if($userdata['gguin'] == '')
+		$userdata['gguin'] = 0;
 
-	if($userdata['gguin'] !='' && !eregi('^[0-9]{4,}$',$userdata['gguin']))
+	if($userdata['gguin']!=0 && !eregi('^[0-9]{4,}$',$userdata['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
 
 	if($userdata['status']!=3&&$LMS->GetUserNodesNo($userdata['id'])) 
@@ -146,70 +201,17 @@ elseif(isset($userdata))
 		$userinfo['shownodes'] = TRUE;
 }
 
-$layout['pagetitle']='Edycja danych uytkownika: '.$userinfo['username'];
+$layout['pagetitle'] = 'Edycja danych uytkownika: '.$userinfo['username'];
 $SMARTY->assign('usernodes',$LMS->GetUserNodes($userinfo['id']));
 $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($userinfo['id']));
 $SMARTY->assign('tariffs',$LMS->GetTariffs());
 $SMARTY->assign('assignments',$LMS->GetUserAssignments($_GET['id']));
+$SMARTY->assign('usergroups',$LMS->UsergroupGetForUser($_GET['id']));
+$SMARTY->assign('otherusergroups',$LMS->GetGroupNamesWithoutUser($_GET['id']));
 $SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('recover',($_GET['action'] == 'recover' ? 1 : 0));
 $SMARTY->display('useredit.html');
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-/*
- * $Log: useredit.php,v $
- * Revision 1.50  2003/12/04 03:43:51  lukasz
- * - dodany PESEL do rekordu uytkownika, upgrade bazy
- *   Jeeli uytkownik nie posiada NIPu, to wtedy na fakturze umieszczany jest
- *   PESEL.
- * - do faktur zostao dodane miejsce wystawienia
- * - zamiana nazewctwa w tabelach z 'sww' na 'pkwiu'
- * - przegenerowane doce
- * - TODO: jeeli na fakturze nie ma pozycji z pkwiu, to usun t kolumen
- *   z faktury.
- * - w choler kosmetyki
- *
- * Revision 1.49  2003/12/02 03:56:41  lukasz
- * - przy pustym polu doda assign na nastpny dzie
- *
- * Revision 1.48  2003/10/22 23:07:52  lukasz
- * - temporary save
- *
- * Revision 1.47  2003/09/26 17:44:10  alec
- * ujednolicone nagwki (dodany ':')
- *
- * Revision 1.46  2003/09/09 20:23:00  lukasz
- * - literwka, czyli Baseciq zna jz. angielski
- *
- * Revision 1.45  2003/09/09 01:50:51  lukasz
- * - YAFBF - Yet Another Fucked Bug Fix
- *
- * Revision 1.44  2003/09/09 01:48:47  lukasz
- * - another bugfix
- *
- * Revision 1.43  2003/09/09 01:24:26  lukasz
- * - cosmetics
- *
- * Revision 1.42  2003/09/09 01:22:28  lukasz
- * - nowe finanse
- * - kosmetyka
- * - bugfixy
- * - i inne rzeczy o ktrych aktualnie nie pamitam
- *
- * Revision 1.41  2003/09/05 13:11:24  lukasz
- * - nowy sposb wywietlania informacji o bdach
- *
- * Revision 1.40  2003/08/25 02:12:24  lukasz
- * - zmieniona obsuga usuwania userw
- *
- * Revision 1.39  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.38  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
